@@ -6,7 +6,7 @@ from typing import List, Mapping, Tuple
 from parse import compile, Parser, Result
 
 from publicator import shell
-from publicator.semver import Semver
+from semmy import Semver
 
 
 class RemoteParser:
@@ -25,7 +25,7 @@ class RemoteParser:
         return named
 
 
-@dataclass(frozen=True)  # pragma: no mutate
+@dataclass(frozen=True)
 class Repo:
     server: str = ""
     owner: str = ""
